/*  
** (C) Copyright 2005 Gary King and Langche Zeng, All Rights Reserved.
** King@Harvard.Edu, lzeng@gwu.edu
** Current version available at http://GKing.Harvard.Edu,
**   
** Inhull: Check membership in a convex hull.
**
** This procedure checks whether the given query points are in the
** convex hull of an observed data matrix. It requires the Gauss Simplex
** module for linear programming.
**
** Usage:    library simplex;
**           hull=inhull(Z,X);
**
** Input:    Z = mxk matrix, the query points.
**           X = Nxk matrix, the data matrix.
**
** Output:   hull = mx1 vector of 1's and 0's. hull[i]=1 if Z[i.,] is in the
**           convex hull of X. hull[i]=0 otherwise.
**
** Globals:   Globals of Simplex are relevant.
**
** Application (code developed for):
**  Gary King and Langche Zeng, "How Factual is Your Counterfactual?" 
**        http://GKing.Harvard.Edu
**
*/
  
proc inhull(z,X);
 local i,j,hull,n,m,k,A,B,C,l,u,beta,f,ret;
      
 /* verify inputs */
  if cols(z) /= cols(X);
    "X and z must have the same number of columns."; end;
  endif;

  n=rows(X);
  k=cols(X);
  m=rows(Z);
  
  lpset;
  __output=0;
  _lpcnst=3;                           @ equality constraints @ 
  _lpstrtx=(ones(n,1)./n)|zeros(k,1); 
  
  A=x'|ones(1,n);
  C=zeros(1,n); 
  l=0;
  u=1;           
  z=z';
  
  hull=zeros(m,1);
  
  for i (1,m,1);
   
    j=1;
    do while j<=rows(X);
        if ismiss(setdif(z[.,i],X[j,.],1));
	   hull[i]=1;
	   break;
	 endif;
       j=j+1;
     endo;
     
     if hull[i]==1;
         continue;
     endif;
       
    B=z[.,i]|1;   
    {beta,f,ret}=simplex(A,B,C,l,u); 
 
    hull[i]=1-(ret==2 or ret<0); 
  
 endfor;

 retp(hull);

endp;



















